Kansas Supreme Court - Opinions Released

Kansas Opinions | Finding Aids: Case Name » Supreme Court or Court of Appeals | Docket Number | Release Date |

Kansas Court of Appeals
Opinions Released June 20, 2014

Published Opinions

Published Opinions are available for viewing with Adobe Acrobat® Reader™.
Cite published opinions using the official citations followed by any generally recognized reporter citation System. SCR 6.08

Docket Number / Case Name
108147 - State v. Lewis
110221 - Chubb v. Sullivan

Unpublished Opinions
Fulltext NOT available on the web.
Contact the Kansas Supreme Court Law Library at 785-296-3257 to obtain fulltext.

Docket Number / Case Name / Judge / Disposition / County
108911 - Farmer v. State – Powell, J. – Affirmed in part, reversed in part, and remanded with directions – Montgomery.
109464 - State v. Wearren – Per Curiam – Affirmed – Geary.
109640 - State v. Vandorn – Per Curiam – Affirmed – Crawford.
109657 - State v. Beck – Per Curiam – Affirmed in part and dismissed in part – Ford.
109668 - State v. Thompson – Per Curiam – Affirmed – Brown.
109721 - State v. Fulson – Per Curiam – Affirmed – Wyandotte.
109743 - Schilling v. Kansas Department of Revenue – Per Curiam – Affirmed – Shawnee.
109823 - Carter v. State – Per Curiam – Affirmed – Montgomery.
109925 - State v. Adams – Per Curiam – Affirmed – Shawnee.
110015 - State v. Carleton – Leben, J. – Affirmed – Jackson.
110028 - In the Matter of the Care and Treatment of Strait – Per Curiam – Affirmed – Brown.
110046 - Fox v. Kansas Department of Revenue – Per Curiam – Affirmed – Ellis.
110052 - Mendez v. Cargill Meat Solutions Corp, et al. – Leben, J. – Affirmed – Appeal from Workers Compensation Board.
110088 - State v. Maberry – Per Curiam – Affirmed in part and dismissed in part – Reno.
110107 - Davis v. State – Per Curiam – Affirmed – Sedgwick.
110110 - State v. Lewis – Per Curiam – Affirmed – Wyandotte.
110154 - Nelson v. Kansas Employment Security Board of Review, et al. – Per Curiam – Affirmed – Saline.
110189 - State v. Tripp – Per Curiam – Affirmed – Leavenworth.
110367 - Schaben v. Central Kansas Medical Center, et al. – Leben, J. – Affirmed – Appeal from Workers Compensation Board.
110424 - In the Matter of the Protest of Mallatt, et al. – Per Curiam – Affirmed – Appeal from Court of Tax Appeals.
110466 - State v. Craig – Per Curiam – Affirmed – Reno.
110588 - State v. Delvalle – Per Curiam – Appeal dismissed – Reno.
110644 - Brown v. State – Per Curiam – Affirmed – Cowley.
110717 - State v. Bowlin – Per Curiam – Affirmed – Ford.
110757 - Muller v. Kansas Department of Revenue – Per Curiam – Affirmed – Republic.
110764 - In the Interest of B.H. and K.H. – Leben, J. – Affirmed – Shawnee.
110818 - State v. Swartz – Per Curiam – Affirmed – Shawnee.
110855 - Cook v. State, et al. – Per Curiam – Appeal dismissed – Appeal from Workers Compensation Board.
110906 - Thomas v. Pryor – Per Curiam – Affirmed – Leavenworth.
110977 - Jamerson v. Heimgartner – Per Curiam – Affirmed – Butler.
111095 - Kingyon v. Roberts – Per Curiam – Affirmed – Leavenworth

NOTE: Slip opinions are subject to modification orders and editorial corrections prior to publication in the official reporters. Consult the bound volumes of Kansas Reports and Kansas Court of Appeals Reports for the final, official texts of the opinions of the Kansas Supreme Court and the Kansas Court of Appeals. Attorneys are requested to call prompt attention to typographical or other formal errors; please notify Richard Ross, Reporter of Decisions, Kansas Judicial Center, 301 West 10th, Topeka, KS 66612-1598; e-mail, rossr@kscourts.org; phone, 785-296-3214.

Kansas Opinions | Finding Aids: Case Name » Supreme Court or Court of Appeals | Docket Number | Release Date |